Package: mosbi
Title: Molecular Signature identification using Biclustering
Version: 1.16.0
Authors@R: c(
  person("Tim Daniel", "Rose", email="tim.rose@wzw.tum.de", 
  role = c("cre", "aut")),
  person("Josch Konstantin", "Pauling", 
  email="josch.pauling@tum.de", role = c("aut")),
  person("Nikolai", "Koehler", 
  email="nikolai.koehler@tum.de", role = c("aut")))
Description: This package is a implementation of biclustering ensemble 
  method MoSBi (Molecular signature Identification from Biclustering).
  MoSBi provides standardized interfaces for biclustering results and 
  can combine their 
  results with a multi-algorithm ensemble approach to compute robust 
  ensemble biclusters on molecular omics data.
  This is done by computing similarity networks of biclusters and 
  filtering for overlaps using a custom error model.
  After that, the louvain modularity it used to extract bicluster 
  communities from the similarity network, which can then be converted 
  to ensemble biclusters.
  Additionally, MoSBi includes several network visualization methods 
  to give an intuitive and scalable overview of the results.
  MoSBi comes with several biclustering algorithms, but can be easily 
  extended to new biclustering algorithms.
License: AGPL-3 + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.1
Depends: R (>= 4.1)
SystemRequirements: C++17, GNU make
LinkingTo: Rcpp, BH, RcppParallel
Imports: Rcpp, BH, xml2, methods, igraph, fabia, RcppParallel, biclust,
        isa2, QUBIC, akmbiclust, RColorBrewer
Suggests: knitr, rmarkdown, BiocGenerics, runibic, BiocStyle, testthat
        (>= 3.0.0)
Collate: 'RcppExports.R' 'bicluster.R' 'bicluster_net_methods.R'
        'ensemble_bicluster.R' 'extract_BicARE.R'
        'extract_akmbiclust.R' 'extract_biclust.R'
        'extract_biclustpy.R' 'extract_fabia.R' 'extract_isa.R'
        'feature_louvain_overlap.R' 'filter_biclusters.R'
        'get_biclusters.R' 'misc.R' 'mosbi-package.R' 'mouse_data.R'
        'pipeline.R' 'run_algorithms.R'
VignetteBuilder: knitr
biocViews: Software, StatisticalMethod, Clustering, Network
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/mosbi
git_branch: RELEASE_3_22
git_last_commit: 798cd83
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: yes
Packaged: 2025-10-30 05:13:40 UTC; biocbuild
Author: Tim Daniel Rose [cre, aut],
  Josch Konstantin Pauling [aut],
  Nikolai Koehler [aut]
Maintainer: Tim Daniel Rose <tim.rose@wzw.tum.de>
