#' Mouse brain lipidomics data
#' 
#' Development of the mice brain lipidome over several weeks.
#' 
#' @format A data frame with 245 rows and 61 columns
#' 
#' @source \url{https://www.ebi.ac.uk/metabolights/MTBLS562}
#' 
#' @usage data(mouse_data)
#' 
#' @examples 
#' # data(mouse_data)
#' # View(mouse_data)
"mouse_data"